﻿/* FMdict.jsx ------ UTF-8 ------------------------------------------------------------------------
                Show information concerning dictionaries
  Documentation www.daube.ch/docu/fmaker77.html
  Comment       To be placed in Startup folder of user area
  Reference     Traduction française avec l'aide de https://www.deepl.com/translator par Klaus Daube
  Copyleft      2018 Klaus Daube, Zürich, Switzerland, klaus@daube.ch
  History       2017-06-30 v1.0
                2018-02-16 v1.7 New command names; Modifications in Inst-FMdict.ahk
*/ ; // ===========================================================================================
#target framemaker

SwitchUILanguage ();
// $.locale = "fr";                               // test with longest texts
ShowDictInfo ()                                   // At start of FM inform about the User dictionary
SetUpMenus()    // inactivate for debugging       // Establish menu item to get the information also later.

function SetUpMenus() { // =========================================================================
// This function MUST NOT be named DefineMenu - because this is a reserved function!
  var sDictMenu  = { en: "Dictionary information",
                     de: "Wörterbuch-information",
                     fr: "Information du disctionnaire"}
  var sShortLbl  = { en: "ESC q d i",
                     de: "ESC q d i",
                     fr: "ESC q d i"};
  var sShortCut  = { en: "\\!qdi",
                     de: "\\!qdi",
                     fr: "\\!qdi"};

  var menuLocation = app.GetNamedMenu("FileMenu");
  var cmdDoc       = menuLocation.DefineAndAddCommand(1, "FMdict_DocInfo", localize(sDictMenu), localize(sShortCut));
  cmdDoc.KeyboardShortcutLabel = localize(sShortLbl);
                                               // --- Menu definition for books
  menuLocation     = app.GetNamedMenu("BookFileMenu");
  var cmdBook      = menuLocation.DefineAndAddCommand(1, "FMdict_BkInfo", localize(sDictMenu), localize(sShortCut));
  cmdBook.KeyboardShortcutLabel = localize(sShortLbl);

  UpdateMenus();                                  // refresh and actually make the new menu appear

} // ---  end SetUpMenus

function Command(cmd){
  switch(cmd) {
    case 1:
     ShowDictInfo();
     break;
  }
} // --- end Command

function ShowDictInfo () { // === Alert the dictionary information ================================
var appdata    = app.UserSettingsDir;             // %appdata%\Roaming\Adobe\FrameMaker\<version>

var FMdictDir  = appdata.replace (/Adobe.*/ , "D+DD\\FMdict");
var iniFile    = FMdictDir + "\\scripts\\FMdict.ini";
var text       = { en: "The User dictionary was loaded from \nFMdict project:\t%1 \nLocated in:  \t%2",
                   de: "Das benutzer-wörterbuch wurde geladen von \nFMdict projekt:\t%1\nDaten in:    \t%2",
                   fr: "Le dictionnaire utilisateur a été chargé à partir de \nFMdict projet :\t%1\nSitué à :      \t%2"};
var title      = { en: "FMdict — Dictionary information",
                   de: "FMdict — Wörterbuch-information",
                   fr: "FMdict — Information du disctionnaire"};
var currentPrj = GetIniValue (iniFile, "currentPrj");
var currentDir = GetIniValue (iniFile, "currentDir");

  if (currentPrj !== "NONE") {                    // must fit with FMdict
    alert (localize (text, currentPrj, currentDir), localize (title), false);
  }
}

function GetIniValue (sIniPath, sValueName) { //==== Read ini item into a variable ================
// sIniPath     Complete path to ini file "...\D+DD\\FMdict\\FMdict.ini"
// sValueName   Value name as used in the ini-file
// Function     returns sFoundValue
  var thisLine, match, notFound = true, settingsFile, sFoundValue;
  var regex = {
    section: /^\s*\[\s*([^\]]*)\s*\]\s*$/,
    param: /^\s*([\w\.\-\_]+)\s*=\s*(.*?)\s*$/,
    comment: /^\s*;.*$/ } ;
  settingsFile = new File(sIniPath);
  settingsFile.open("r");
  if (settingsFile.error !== "") {
    Alert ("GetIniValue: Open error for file " + sIniPath, Constants.FF_ALERT_CONTINUE_WARN);
    return "Ini-read-error"
  }

  while(!settingsFile.eof) {
    thisLine = settingsFile.readln();
    if (thisLine === null || thisLine === "") {   // skip blank lines
      continue;
    }
    if (regex.comment.test(thisLine))  {          // skip comment lines
      continue;
    }
    if (regex.section.test(thisLine))  {          // ignore section lines
      continue;
    }

    match = thisLine.match(regex.param);          // ignore undefined contents

    if (match[1] == sValueName) {
      sFoundValue = match[2];
      notFound = false;
      break;                                      // found - leave loop
    }
  }
  if (notFound) {
   sFoundValue = sValueName + " not found in " + sIniPath
  }
  settingsFile.close();
  return sFoundValue;
} // --- end GetIniValue

function SwitchUILanguage () {; // === Switch language according to application language ==========
  switch (app.Language) {
    case Constants.FV_LANG_BRITISH:
    case Constants.FV_LANG_ENGLISH: {
      $.locale = "en"; break;
    }
    case Constants.FV_LANG_CANADIAN_FRENCH:
    case Constants.FV_LANG_FRENCH: {
      $.locale = "fr"; break;
    }
    case Constants.FV_LANG_GERMAN:
    case Constants.FV_LANG_NEW_GERMAN:
    case Constants.FV_LANG_NEW_SWISS_GERMAN:
    case Constants.FV_LANG_SWISS_GERMAN:	{
      $.locale = "de"; break;
    }
    default: {
      $.locale = "en"; break;
    }
  }
} // --- end SwitchUILanguage
